Summary:    Open Geographic Datastore Interface
Name:       ogdi
Version:    4.1.0
Release:    3%{?dist}
License:    BSD
URL:        http://ogdi.sourceforge.net/

%global     gitversion %(echo "%version" | sed 's/\\\./\\\_/g')

Source0:    https://github.com/libogdi/ogdi/archive/%{name}_%{gitversion}.tar.gz

Patch3000:  ogdi-%{version}-sailer.patch
Patch3001:  ogdi-c99.patch

BuildRequires: expat-devel tcl-devel libtirpc-devel
BuildRequires: make gcc unixODBC-devel zlib-devel

%description
OGDI is the Open Geographic Datastore Interface. OGDI is an
application programming interface (API) that uses a standardized
access methods to work in conjunction with GIS software packages (the
application) and various geospatial data products. OGDI uses a
client/server architecture to facilitate the dissemination of
geospatial data products over any TCP/IP network, and a
driver-oriented approach to facilitate access to several geospatial
data products/formats.


%package devel
Summary:    OGDI header files and documentation
Requires:    %{name} = %{version}-%{release}
Requires:    pkgconfig
Requires:    zlib-devel expat-devel

%description devel
OGDI header files and developer's documentation.


%package odbc
Summary:    ODBC driver for OGDI
Requires:    %{name} = %{version}-%{release}

%description odbc
ODBC driver for OGDI.


%package tcl
Summary:    TCL wrapper for OGDI
Requires:    %{name} = %{version}-%{release}

%description tcl
TCL wrapper for OGDI.


%prep
%autosetup -p1 -n %{name}-%{name}_%{gitversion}



%build
TOPDIR=`pwd`; TARGET=Linux; export TOPDIR TARGET
INST_LIB=%{_libdir}/;export INST_LIB

export CFG=debug
export CFLAGS="$RPM_OPT_FLAGS -DDONT_TD_VOID -DUSE_TERMIO"
%configure \
    --with-binconfigs \
    --with-expat \
    --with-zlib

make

make -C ogdi/tcl_interface \
    TCL_LINKLIB="-ltcl"

make -C contrib/gdal

make -C ogdi/attr_driver/odbc \
    ODBC_LINKLIB="-lodbc"

%install
TOPDIR=`pwd`; TARGET=Linux; export TOPDIR TARGET

make install \
    INST_INCLUDE=%{buildroot}%{_includedir}/%{name} \
    INST_LIB=%{buildroot}%{_libdir} \
    INST_BIN=%{buildroot}%{_bindir}

make install -C ogdi/tcl_interface \
    INST_LIB=%{buildroot}%{_libdir}
make install -C contrib/gdal \
    INST_LIB=%{buildroot}%{_libdir}
make install -C ogdi/attr_driver/odbc \
    INST_LIB=%{buildroot}%{_libdir}

rm %{buildroot}%{_bindir}/example?

touch -r ogdi-config.in ogdi-config

mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -p -m 644 ogdi.pc %{buildroot}%{_libdir}/pkgconfig/
install -p -m 755 ogdi-config %{buildroot}%{_bindir}/ogdi-config-%{__isa_bits}
cat > %{buildroot}%{_bindir}/%{name}-config <<EOF
#!/bin/bash

ARCH=\$(uname -m)
case \$ARCH in
x86_64 | ppc64le | aarch64 )
ogdi-config-64 \${*}
;;
*)
ogdi-config-32 \${*}
;;
esac
EOF
chmod 755 %{buildroot}%{_bindir}/%{name}-config
touch -r ogdi-config.in %{buildroot}%{_bindir}/%{name}-config


%files
%doc LICENSE NEWS ChangeLog README
%{_bindir}/gltpd
%{_bindir}/ogdi_*
%{_libdir}/libogdi.so.*
%dir %{_libdir}/ogdi
%exclude %{_libdir}/%{name}/liblodbc.so
%exclude %{_libdir}/%{name}/libecs_tcl.so
%{_libdir}/%{name}/lib*.so

%files devel
%doc ogdi/examples/example1/example1.c
%doc ogdi/examples/example2/example2.c
%{_bindir}/%{name}-config
%{_bindir}/%{name}-config-%{__isa_bits}
%{_libdir}/libogdi.so
%{_libdir}/pkgconfig/%{name}.pc
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h

%files odbc
%{_libdir}/%{name}/liblodbc.so

%files tcl
%{_libdir}/%{name}/libecs_tcl.so


%changelog
* Thu Aug 03 2023 cunshunxia <cunshunxia@tencent.com> - 4.1.0-3
- Rebuilt for tcl 8.6.13

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.1.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Apr 21 2023 cunshunxia <cunshunxia@tencent.com> - 4.1.0-1
- initial build
